@@ -1,8 +1,5 @@
-from .urdf_parser_py.urdf import URDF, Mesh, Cylinder, Box, Sphere
-from . import frame
-from . import chain
-from . import transform
-
+from . import chain, frame, transform
+from .urdf_parser_py.urdf import URDF, Box, Cylinder, Mesh, Sphere
 
 JOINT_TYPE_MAP = {'revolute': 'revolute',
                   'continuous': 'revolute',
